@@ -1,7 +1,7 @@
 /* Part of the bison parser generator,
 
-   Copyright (C) 2000, 2002, 2009-2015, 2018 Free Software Foundation,
-   Inc.
+   Copyright (C) 2000, 2002, 2009-2015, 2018-2020 Free Software
+   Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
